<?php
/**
 * File for the interface class
 *
 * @package zeus-gpt
 */

// shortcode class.
require_once dirname( __FILE__ ) . '/widgets/class-zeusgptshortcode.php';

/**
 * Interface Class
 */
class ZeusGPTInterface {
	/**
	 * Registers all the interfaces
	 *
	 * @return void
	 */
	public function __construct() {
		// elementor.
		add_action( 'elementor/widgets/register', array( $this, 'register_elementor_widget' ) );
		add_action( 'elementor/elements/categories_registered', array( $this, 'register_elementor_category' ) );

		// shortcode.
		ZeusGPTShortcode::register();

		// register gutenberg block category.
		if ( version_compare( $GLOBALS['wp_version'], '5.8-alpha-1', '<' ) ) {
			add_filter( 'block_categories', array( __CLASS__, 'register_custom_category' ) );
		} else {
			add_filter( 'block_categories_all', array( $this, 'register_custom_category' ) );
		}
	}

	/**
	 * Registers Elementor widget
	 *
	 * @param  object $widgets_manager - The widget manager object.
	 * @return void
	 */
	public function register_elementor_widget( $widgets_manager ) {
		if ( ! class_exists( '\Elementor\Widget_Base' ) ) {
			return;
		}

		require_once dirname( __FILE__ ) . '/widgets/class-zeusgptelementor.php';
		$widgets_manager->register( new ZeusGPTElementor() );
	}

	/**
	 * Registers Elementor category
	 *
	 * @param  object $elements_manager  - The elements manager object.
	 * @return void
	 */
	public function register_elementor_category( $elements_manager ) {
		$elements_manager->add_category(
			'gfxpartner',
			array(
				'title' => esc_html__( 'Gfxpartner', 'zeus-gpt' ),
				'icon'  => 'fa fa-plug',
			)
		);
	}

	/**
	 * Registers custom category for the Gutenberg Editor
	 *
	 * @param  array $categories - list of categories.
	 * @return array
	 */
	public function register_custom_category( $categories ) {
		array_push(
			$categories,
			array(
				'slug'  => 'gfxpartner',
				'title' => esc_html__( 'Gfxpartner', 'zeus-gpt' ),
				'icon'  => null,
			)
		);

		return $categories;
	}

}
