<?php
/**
 * File for the Elementor widget
 *
 * @package zeus-gpt
 */

/**
 * Elementor widget
 */
class ZeusGPTElementor extends \Elementor\Widget_Base {

	/**
	 * Unique identifier of the widget.
	 *
	 * @return string
	 */
	public function get_name() {
		return 'gfx_zeus_gpt_elementor_widget';
	}

	/**
	 * Name of the widget that is visible to the user.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'ZeusGPT', 'zeus-gpt' );
	}

	/**
	 * The icon to display next to the title.
	 *
	 * @return string
	 */
	public function get_icon() {
		return 'eicon-notes';
	}

	/**
	 * The category the widget belongs to.
	 *
	 * @return array
	 */
	public function get_categories() {
		return array( 'gfxpartner' );
	}

	/**
	 * Scripts this widget is dependent on.
	 *
	 * @return array
	 */
	public function get_script_depends() {
		return array( 'gfx-zeus-main-public' );
	}

	/**
	 * Styles this widget is dependent on.
	 *
	 * @return array
	 */
	public function get_style_depends() {
		return array( 'space-grotesk', 'gfx-zeus-main-public' );
	}

	/**
	 * Call of action controls
	 *
	 * @return void
	 */
	private function call_to_action() {
		$this->start_controls_section(
			'widget_call_to_action',
			array(
				'label' => esc_html__( 'Call to Action', 'zeus-gpt' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'call_to_action_link',
			array(
				'label'       => esc_html__( 'Link', 'zeus-gpt' ),
				'type'        => \Elementor\Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'zeus-gpt' ),
				'options'     => array( 'url', 'is_external', 'nofollow' ),
				'label_block' => true,
				'dynamic'     => array(
					'active' => true,
				),
			)
		);

		$this->add_control(
			'call_to_action_icon',
			array(
				'label' => esc_html__( 'Icon', 'zeus-gpt' ),
				'type'  => \Elementor\Controls_Manager::ICONS,
			)
		);

		$this->end_controls_section();
	}

	/**
	 * Call to action styles
	 *
	 * @return void
	 */
	private function call_to_action_styles() {
		$this->start_controls_section(
			'widget_call_to_action_style',
			array(
				'label' => esc_html__( 'Call to Action', 'zeus-gpt' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);

		$this->start_controls_tabs( 'call_to_action_tabs' );

		$this->start_controls_tab(
			'cta_normal',
			array(
				'label' => esc_html__( 'Normal', 'zeus-gpt' ),
			)
		);

		$this->add_control(
			'cta_bg_color',
			array(
				'label'     => esc_html__( 'Background Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-form .cta-btn' => 'background-color: {{VALUE}} !important;',
				),
			)
		);

		$this->add_control(
			'cta_text_color',
			array(
				'label'     => esc_html__( 'Text Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-form .cta-btn' => 'color: {{VALUE}}',
					'{{WRAPPER}} .gfx-zeus-chat-form .cta-btn svg' => 'fill: {{VALUE}}',
				),
			)
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'cta_hover',
			array(
				'label' => esc_html__( 'Hover', 'zeus-gpt' ),
			)
		);

		$this->add_control(
			'cta_bg_color_hover',
			array(
				'label'     => esc_html__( 'Background Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-form .cta-btn:hover' => 'background-color: {{VALUE}} !important;',
				),
			)
		);

		$this->add_control(
			'cta_text_color_hover',
			array(
				'label'     => esc_html__( 'Text Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-form .cta-btn:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .gfx-zeus-chat-form .cta-btn:hover svg' => 'fill: {{VALUE}}',
				),
			)
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();
	}

	/**
	 * Content controls
	 *
	 * @return void
	 */
	private function content_controls() {
		$this->start_controls_section(
			'widget_content',
			array(
				'label' => esc_html__( 'Content', 'zeus-gpt' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'fixed',
			array(
				'label'        => esc_html__( 'Display in corner', 'zeus-gpt' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'zeus-gpt' ),
				'label_off'    => esc_html__( 'No', 'zeus-gpt' ),
				'return_value' => 'yes',
				'default'      => 'no',
			)
		);

		$this->add_control(
			'fixed_left',
			array(
				'label'        => esc_html__( 'Left corner', 'zeus-gpt' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'zeus-gpt' ),
				'label_off'    => esc_html__( 'No', 'zeus-gpt' ),
				'return_value' => 'yes',
				'default'      => 'no',
				'condition'    => array(
					'fixed' => 'yes',
				),
			)
		);

		$this->add_control(
			'prompt_behaviour',
			array(
				'label'       => esc_html__( 'Behaviour', 'zeus-gpt' ),
				'type'        => \Elementor\Controls_Manager::TEXTAREA,
				'rows'        => 10,
				'placeholder' => esc_html__( 'Example: Your name is John Doe. You are head of marketing.', 'zeus-gpt' ),
				'dynamic'     => array(
					'active' => true,
				),
			)
		);

		$this->add_control(
			'welcome_message',
			array(
				'label'   => esc_html__( 'Welcome message', 'zeus-gpt' ),
				'type'    => \Elementor\Controls_Manager::TEXTAREA,
				'rows'    => 10,
				'default' => esc_html__( 'Start chatting with your favorite AI.', 'zeus-gpt' ),
				'dynamic' => array(
					'active' => true,
				),
			)
		);

		$this->add_control(
			'welcome_message_tag',
			array(
				'label'   => esc_html__( 'Welcome message tag', 'zeus-gpt' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'default' => 'p',
				'options' => array(
					'h1'   => esc_html__( 'H1', 'zeus-gpt' ),
					'h2'   => esc_html__( 'H2', 'zeus-gpt' ),
					'h3'   => esc_html__( 'H3', 'zeus-gpt' ),
					'h4'   => esc_html__( 'H4', 'zeus-gpt' ),
					'h5'   => esc_html__( 'H5', 'zeus-gpt' ),
					'h6'   => esc_html__( 'H6', 'zeus-gpt' ),
					'p'    => esc_html__( 'P', 'zeus-gpt' ),
					'span' => esc_html__( 'SPAN', 'zeus-gpt' ),
				),
			)
		);

		$this->add_control(
			'input_placeholder',
			array(
				'label'       => esc_html__( 'Placeholder', 'zeus-gpt' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => esc_html__( 'Type a message.', 'zeus-gpt' ),
				'label_block' => true,
				'dynamic'     => array(
					'active' => true,
				),
			)
		);

		$this->end_controls_section();
	}

	/**
	 * General styles
	 *
	 * @return void
	 */
	private function general_styles() {
		$this->start_controls_section(
			'general_styles',
			array(
				'label' => esc_html__( 'General message', 'zeus-gpt' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'general_message_color',
			array(
				'label'     => esc_html__( 'Background Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-container' => '--main-background-color: {{VALUE}}',
				),
			)
		);

		$this->end_controls_section();
	}

	/**
	 * Personal message styles
	 *
	 * @return void
	 */
	private function personal_message_styles() {
		$this->start_controls_section(
			'personal_message_styles',
			array(
				'label' => esc_html__( 'Personal message', 'zeus-gpt' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'personal_message_typography',
				'selector' => '{{WRAPPER}} .gfx-zeus-chat-container .gfx-zeus-chat-conversation .chat-element.chat-element--personal',
			)
		);

		$this->add_control(
			'personal_message_color',
			array(
				'label'     => esc_html__( 'Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-container .gfx-zeus-chat-conversation .chat-element.chat-element--personal' => 'color: {{VALUE}}',
				),
			)
		);

		$this->add_control(
			'personal_message_bg_color',
			array(
				'label'     => esc_html__( 'Background Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-container .gfx-zeus-chat-conversation .chat-element.chat-element--personal' => 'background-color: {{VALUE}}',
				),
			)
		);

		$this->end_controls_section();
	}

	/**
	 * Response message styles
	 *
	 * @return void
	 */
	private function response_message_styles() {
		$this->start_controls_section(
			'response_message_styles',
			array(
				'label' => esc_html__( 'Response message', 'zeus-gpt' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'response_message_typography',
				'selector' => '{{WRAPPER}} .gfx-zeus-chat-container .gfx-zeus-chat-conversation .chat-element:not(.chat-element--personal)',
			)
		);

		$this->add_control(
			'response_message_color',
			array(
				'label'     => esc_html__( 'Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-container .gfx-zeus-chat-conversation .chat-element:not(.chat-element--personal)' => 'color: {{VALUE}}',
				),
			)
		);

		$this->add_control(
			'response_message_bg_color',
			array(
				'label'     => esc_html__( 'Background color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-container .gfx-zeus-chat-conversation .chat-element:not(.chat-element--personal)' => 'background-color: {{VALUE}}',
				),
			)
		);

		$this->end_controls_section();

	}

	/**
	 * Prompt styles
	 *
	 * @return void
	 */
	private function prompt_styles() {
		$this->start_controls_section(
			'input_styling',
			array(
				'label' => esc_html__( 'Input', 'zeus-gpt' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'prompt_border_radius',
			array(
				'label'      => esc_html__( 'Border radius', 'zeus-gpt' ),
				'type'       => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'em', 'rem' ),
				'selectors'  => array(
					'{{WRAPPER}} .gfx-zeus-chat-prompt' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			)
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			array(
				'name'     => 'prompt_border',
				'selector' => '{{WRAPPER}} .gfx-zeus-chat-prompt',
			)
		);

		$this->add_control(
			'prompt_bg_color',
			array(
				'label'     => esc_html__( 'Background Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-prompt' => 'background-color: {{VALUE}}',
				),
			)
		);

		$this->add_control(
			'prompt_text_color',
			array(
				'label'     => esc_html__( 'Text Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-prompt' => 'color: {{VALUE}}',
				),
			)
		);

		$this->end_controls_section();
	}

	/**
	 * Button styles
	 *
	 * @return void
	 */
	private function button_styles() {
		$this->start_controls_section(
			'button_styling',
			array(
				'label' => esc_html__( 'Button', 'zeus-gpt' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'button_icon',
			array(
				'label' => esc_html__( 'Icon', 'zeus-gpt' ),
				'type'  => \Elementor\Controls_Manager::ICONS,
			)
		);

		$this->add_control(
			'button_border_radius',
			array(
				'label'      => esc_html__( 'Border radius', 'zeus-gpt' ),
				'type'       => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'em', 'rem' ),
				'selectors'  => array(
					'{{WRAPPER}} .gfx-zeus-chat-form .submit' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
				),
			)
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			array(
				'name'     => 'button_border',
				'selector' => '{{WRAPPER}} .gfx-zeus-chat-form .submit',
			)
		);

		$this->start_controls_tabs( 'button_tabs' );

		$this->start_controls_tab(
			'button_normal',
			array(
				'label' => esc_html__( 'Normal', 'zeus-gpt' ),
			)
		);

		$this->add_control(
			'button_bg_color',
			array(
				'label'     => esc_html__( 'Background Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-form .submit' => 'background-color: {{VALUE}} !important;',
				),
			)
		);

		$this->add_control(
			'button_text_color',
			array(
				'label'     => esc_html__( 'Text Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-form .submit' => 'color: {{VALUE}}',
					'{{WRAPPER}} .gfx-zeus-chat-form .submit svg' => 'fill: {{VALUE}}',
				),
			)
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'button_hover',
			array(
				'label' => esc_html__( 'Hover', 'zeus-gpt' ),
			)
		);

		$this->add_control(
			'button_bg_color_hover',
			array(
				'label'     => esc_html__( 'Background Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-form .submit:hover' => 'background-color: {{VALUE}} !important;',
				),
			)
		);

		$this->add_control(
			'button_text_color_hover',
			array(
				'label'     => esc_html__( 'Text Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-form .submit:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .gfx-zeus-chat-form .submit:hover svg' => 'fill: {{VALUE}}',
				),
			)
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();
	}

	/**
	 * Welcome message styles
	 *
	 * @return void
	 */
	private function welcome_message_styles() {
		$this->start_controls_section(
			'welcome_message_styles',
			array(
				'label' => esc_html__( 'Welcome message', 'zeus-gpt' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'welcome_message_icon',
			array(
				'label' => esc_html__( 'Icon', 'zeus-gpt' ),
				'type'  => \Elementor\Controls_Manager::ICONS,
			)
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'welcome_message_typography',
				'selector' => '{{WRAPPER}} .gfx-zeus-chat-container .gfx-zeus-chat-empty h1',
			)
		);

		$this->add_control(
			'welcome_message_color',
			array(
				'label'     => esc_html__( 'Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-container .gfx-zeus-chat-empty h1' => 'color: {{VALUE}}',
				),
			)
		);

		$this->add_control(
			'welcome_icon_color',
			array(
				'label'     => esc_html__( 'Icon color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-container .gfx-zeus-chat-empty .icon svg' => 'fill: {{VALUE}}',
				),
			)
		);

		$this->add_control(
			'welcome_icon_bg_color',
			array(
				'label'     => esc_html__( 'Icon background color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-container .gfx-zeus-chat-empty .icon' => 'background-color: {{VALUE}}',
				),
			)
		);

		$this->end_controls_section();
	}

	/**
	 * Fixed icon styles
	 *
	 * @return void
	 */
	private function fixed_icon_styles() {
		$this->start_controls_section(
			'fixed_icon_styling',
			array(
				'label' => esc_html__( 'Fixed icon', 'zeus-gpt' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'fixed_icon_icon',
			array(
				'label' => esc_html__( 'Icon', 'zeus-gpt' ),
				'type'  => \Elementor\Controls_Manager::ICONS,
			)
		);

		$this->add_control(
			'fixed_icon_border_radius',
			array(
				'label'      => esc_html__( 'Border radius', 'zeus-gpt' ),
				'type'       => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'em', 'rem' ),
				'selectors'  => array(
					'{{WRAPPER}} .gfx-zeus-chat-container-fixed .gfx-zeus-fixed-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
				),
			)
		);

		$this->start_controls_tabs( 'fixed_icon_tabs' );

		$this->start_controls_tab(
			'fixed_icon_normal',
			array(
				'label' => esc_html__( 'Normal', 'zeus-gpt' ),
			)
		);

		$this->add_control(
			'fixed_icon_bg_color',
			array(
				'label'     => esc_html__( 'Background Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-container-fixed .gfx-zeus-fixed-icon' => 'background-color: {{VALUE}} !important;',
				),
			)
		);

		$this->add_control(
			'fixed_icon_icon_color',
			array(
				'label'     => esc_html__( 'Icon Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-container-fixed .gfx-zeus-fixed-icon' => 'color: {{VALUE}}',
					'{{WRAPPER}} .gfx-zeus-chat-container-fixed .gfx-zeus-fixed-icon svg' => 'fill: {{VALUE}}',
				),
			)
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'fixed_icon_hover',
			array(
				'label' => esc_html__( 'Hover', 'zeus-gpt' ),
			)
		);

		$this->add_control(
			'fixed_icon_bg_color_hover',
			array(
				'label'     => esc_html__( 'Background Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-container-fixed .gfx-zeus-fixed-icon:hover' => 'background-color: {{VALUE}} !important;',
				),
			)
		);

		$this->add_control(
			'fixed_icon_icon_color_hover',
			array(
				'label'     => esc_html__( 'Text Color', 'zeus-gpt' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gfx-zeus-chat-container-fixed .gfx-zeus-fixed-icon:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .gfx-zeus-chat-container-fixed .gfx-zeus-fixed-icon:hover svg' => 'fill: {{VALUE}}',
				),
			)
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();
	}

	/**
	 * Registers the controls
	 *
	 * @return void
	 */
	protected function register_controls() {

		$this->content_controls();
		$this->call_to_action();

		$this->general_styles();
		$this->personal_message_styles();
		$this->response_message_styles();
		$this->prompt_styles();
		$this->button_styles();
		$this->welcome_message_styles();
		$this->fixed_icon_styles();
		$this->call_to_action_styles();
	}

	/**
	 * Renders the chat.
	 *
	 * @return void
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$is_fixed      = 'yes' === $settings['fixed'];
		$is_left_fixed = 'yes' === $settings['fixed_left'];

		?>
		<?php if ( $is_fixed && ! $is_left_fixed ) : ?>
			<div class="gfx-zeus-chat-container-fixed">
		<?php elseif ( $is_fixed && $is_left_fixed ) : ?>
			<div class="gfx-zeus-chat-container-fixed gfx-zeus-chat-container-fixed-left">
		<?php endif; ?> 
		<div class="gfx-zeus-chat-container">
			<div class="gfx-zeus-chat">
				<div class="gfx-zeus-chat-empty">
					<div class="icon">
						<?php if ( ! empty( $settings['welcome_message_icon']['value'] ) ) : ?>
							<?php \Elementor\Icons_Manager::render_icon( $settings['welcome_message_icon'], array( 'aria-hidden' => 'true' ) ); ?>
						<?php else : ?>
							<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M447.1 0h-384c-35.25 0-64 28.75-64 63.1v287.1c0 35.25 28.75 63.1 64 63.1h96v83.1c0 9.838 11.03 15.55 19.12 9.7l124.9-93.7h144c35.25 0 64-28.75 64-63.1V63.1C511.1 28.75 483.2 0 447.1 0zM480 352c0 17.6-14.4 32-32 32h-144.1c-6.928 0-13.67 2.248-19.21 6.406L192 460v-60c0-8.838-7.164-16-16-16H64c-17.6 0-32-14.4-32-32V64c0-17.6 14.4-32 32-32h384c17.6 0 32 14.4 32 32V352zM128 184c-13.25 0-24 10.74-24 24c0 13.25 10.75 24 24 24S152 221.3 152 208C152 194.7 141.3 184 128 184zM384 184c-13.25 0-24 10.74-24 24c0 13.25 10.75 24 24 24s24-10.75 24-24C408 194.7 397.3 184 384 184zM256 184c-13.25 0-24 10.74-24 24c0 13.25 10.75 24 24 24s24-10.75 24-24C280 194.7 269.3 184 256 184z"/></svg>
						<?php endif; ?>
					</div>

					<<?php echo esc_html( $settings['welcome_message_tag'] ); ?> class="message">
						<?php echo esc_html( $settings['welcome_message'] ); ?>
					</<?php echo esc_html( $settings['welcome_message_tag'] ); ?>>
				</div>
				<div class="gfx-zeus-chat-conversation">
				</div>
				<form class="gfx-zeus-chat-form <?php echo esc_attr( ! empty( $settings['call_to_action_link']['url'] ) ? 'has-cta' : '' ); ?>">

					<!-- cta button - start -->

					<?php if ( ! empty( $settings['call_to_action_link']['url'] ) ) : ?>
						<a class="cta-btn hover-btn-1" href="<?php echo esc_url( $settings['call_to_action_link']['url'] ); ?>" target="_blank">
							<?php if ( ! empty( $settings['call_to_action_icon']['value'] ) ) : ?>
								<?php \Elementor\Icons_Manager::render_icon( $settings['call_to_action_icon'], array( 'aria-hidden' => 'true' ) ); ?>
							<?php else : ?>
								<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M448 64H64C28.65 64 0 92.65 0 128v256c0 35.35 28.65 64 64 64h384c35.35 0 64-28.65 64-64V128C512 92.65 483.3 64 448 64zM64 112h384c8.822 0 16 7.178 16 16v22.16l-166.8 138.1c-23.19 19.28-59.34 19.27-82.47 .0156L48 150.2V128C48 119.2 55.18 112 64 112zM448 400H64c-8.822 0-16-7.178-16-16V212.7l136.1 113.4C204.3 342.8 229.8 352 256 352s51.75-9.188 71.97-25.98L464 212.7V384C464 392.8 456.8 400 448 400z"/></svg>
							<?php endif; ?>
						</a>
					<?php endif; ?>

					<!-- cta button - end -->



					<div 
					class="gfx-zeus-chat-prompt" 
					autocomplete="off" 
					autocorrect="off" 
					spellcheck="true" 
					aria-expanded="false" 
					aria-autocomplete="list" 
					aria-multiline="true" 
					aria-label="<?php echo esc_attr__( 'Message', 'zeus-gpt' ); ?>" 
					dir="auto" 
					contenteditable="true" 
					role="textbox"
					placeholder="<?php echo esc_attr( $settings['input_placeholder'] ); ?>"
					></div>
					


					<input type="hidden" name="chat-behaviour" value="<?php echo esc_attr( $settings['prompt_behaviour'] ); ?>">
					<button class="submit hover-btn-1" type="submit">
						<?php if ( ! empty( $settings['button_icon']['value'] ) ) : ?>
							<?php \Elementor\Icons_Manager::render_icon( $settings['button_icon'], array( 'aria-hidden' => 'true' ) ); ?>
						<?php else : ?>
							<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path d="M264.6 70.63l176 168c4.75 4.531 7.438 10.81 7.438 17.38s-2.688 12.84-7.438 17.38l-176 168c-9.594 9.125-24.78 8.781-33.94-.8125c-9.156-9.5-8.812-24.75 .8125-33.94l132.7-126.6H24.01c-13.25 0-24.01-10.76-24.01-24.01s10.76-23.99 24.01-23.99h340.1l-132.7-126.6C221.8 96.23 221.5 80.98 230.6 71.45C239.8 61.85 254.1 61.51 264.6 70.63z"/></svg>
						<?php endif; ?>
					</button>
				</form>
			</div>  
		</div>
		<?php if ( $is_fixed ) : ?>
			<div class="gfx-zeus-fixed-icon">
				<div class="main-icon">
					<?php if ( ! empty( $settings['fixed_icon_icon']['value'] ) ) : ?>
						<?php \Elementor\Icons_Manager::render_icon( $settings['fixed_icon_icon'], array( 'aria-hidden' => 'true' ) ); ?>
					<?php else : ?>
						<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M447.1 0h-384c-35.25 0-64 28.75-64 63.1v287.1c0 35.25 28.75 63.1 64 63.1h96v83.1c0 9.838 11.03 15.55 19.12 9.7l124.9-93.7h144c35.25 0 64-28.75 64-63.1V63.1C511.1 28.75 483.2 0 447.1 0zM480 352c0 17.6-14.4 32-32 32h-144.1c-6.928 0-13.67 2.248-19.21 6.406L192 460v-60c0-8.838-7.164-16-16-16H64c-17.6 0-32-14.4-32-32V64c0-17.6 14.4-32 32-32h384c17.6 0 32 14.4 32 32V352zM128 184c-13.25 0-24 10.74-24 24c0 13.25 10.75 24 24 24S152 221.3 152 208C152 194.7 141.3 184 128 184zM384 184c-13.25 0-24 10.74-24 24c0 13.25 10.75 24 24 24s24-10.75 24-24C408 194.7 397.3 184 384 184zM256 184c-13.25 0-24 10.74-24 24c0 13.25 10.75 24 24 24s24-10.75 24-24C280 194.7 269.3 184 256 184z"/></svg>
					<?php endif; ?>
				</div>
				<div class="sub-icon">
					<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 320 512"><path d="M315.3 411.3c-6.253 6.253-16.37 6.253-22.63 0L160 278.6l-132.7 132.7c-6.253 6.253-16.37 6.253-22.63 0c-6.253-6.253-6.253-16.37 0-22.63L137.4 256L4.69 123.3c-6.253-6.253-6.253-16.37 0-22.63c6.253-6.253 16.37-6.253 22.63 0L160 233.4l132.7-132.7c6.253-6.253 16.37-6.253 22.63 0c6.253 6.253 6.253 16.37 0 22.63L182.6 256l132.7 132.7C321.6 394.9 321.6 405.1 315.3 411.3z"/></svg>
				</div>
			</div>
		</div>
		<?php endif; ?>  
		<?php
	}
}
