<?php
/**
 * File containing the boarding class
 *
 * @package zeus-gpt
 */

// Rate limiter class.
require_once ZEUS_GPT_PLUGIN_DIR . '/inc/services/class-zeusgptratelimiter.php';

// Constants class.
require_once ZEUS_GPT_PLUGIN_DIR . '/inc/misc/class-zeusgptconstants.php';

// Chatlog class.
require_once ZEUS_GPT_PLUGIN_DIR . '/inc/services/class-zeusgptchatlog.php';


/**
 * Class responsible for activation/deactivation functionality
 */
class ZeusGPTBoarding {
	/**
	 * Handles the activation functionality
	 *
	 * @return void
	 */
	public static function activation() {
		ZeusGPTRateLimiter::activation();
		ZeusGPTChatLog::activation();
	}

	/**
	 * Handles the deactivation functionality
	 *
	 * @return void
	 */
	public static function deactivation() {
		ZeusGPTRateLimiter::deactivation();
	}

	/**
	 * Handles the uninstall functionality
	 *
	 * @return void
	 */
	public static function uninstall() {
		self::delete_options();
		ZeusGPTChatLog::uninstall();
	}

	/**
	 * Deletes all the options created by the plugin.
	 *
	 * @return void
	 */
	public static function delete_options() {
		$options = array(
			'gfx_zeus_api_key',
			'gfx_zeus_customizations',
			'gfx_zeus_rate_limiting',
			'gfx_zeus_rate_limit',
			'gfx_zeus_chatlog_toggle',
			'gfx_zeus_chatlog_delete_toggle_popup',
		);
		foreach ( $options as $option ) {
			if ( get_option( $option ) === false ) {
				continue;
			}
			delete_option( $option );
		}
	}
}
