<?php
/**
 * File for the Customizer class
 *
 * @package zeus-gpt
 */

/**
 * Class responsible for the customization
 */
class ZeusGPTCustomizer {
	/**
	 * Constructor
	 *
	 * @return void
	 */
	public function __construct() {
		add_action( 'wp_head', array( $this, 'output_handler' ) );
		add_action( 'admin_head', array( $this, 'output_handler' ) );
	}


	/**
	 * Stores the styles in the Database.
	 *
	 * @return bool
	 */
	public static function handle_input() {

		$customizations = get_option( 'gfx_zeus_customizations' );
		$result         = array();
		if ( $customizations ) {
			$result = $customizations;
		}

        // phpcs:ignore
        foreach ( $_POST as $key => $value ) {
			$key   = sanitize_text_field( wp_unslash( $key ) );
			$value = sanitize_text_field( wp_unslash( $value ) );

			if ( strpos( $key, '||' ) === false ) {
				continue;
			}

			$attributes = explode( '||', $key );

			$selector = $attributes[0];
			$property = $attributes[1];

			// selector already exists.
			if ( array_key_exists( $selector, $result ) ) {
				// property exists.
				if ( array_key_exists( $property, $result[ $selector ] ) ) {
					$result[ $selector ][ $property ] = $value;
				} else {
					$result[ $selector ] += array( $property => $value );
				}
			} else {
				$result[ $selector ]  = array();
				$result[ $selector ] += array( $property => $value );
			}
		}

		if ( ! empty( $customizations ) ) {
			return update_option( 'gfx_zeus_customizations', $result, false );
		} else {
			return add_option( 'gfx_zeus_customizations', $result, '', false );
		}
	}


	/**
	 * Outputs the styles
	 *
	 * @return void
	 */
	public function output_handler() {
		$customizations = get_option( 'gfx_zeus_customizations' );
		if ( ! $customizations ) {
			return;
		}

		/**
		 * The example structure of the customization option is as follows.
		 * [
		 *  'body' => [
		 *      'background-color' => 'black'
		 *  ]
		 * ]
		 */

		echo wp_kses( '<style>', 'zeusgpt-icon' );

		foreach ( $customizations as $selector => $styles ) {
			echo esc_html( $selector . '{' );
			foreach ( $styles as $property => $value ) {
				echo esc_html( $property . ':' . $value . ';' );
			}

			echo esc_html( '}' );
		}

		echo wp_kses( '</style>', 'zeusgpt-icon' );
	}

	/**
	 * Gets the customization value against a selector and property
	 *
	 * @param string $name - name of the input field.
	 * @param string $default - default value to be returned if nothing is found.
	 * @return string
	 */
	public static function get_customization_value( $name, $default ) {
		if ( null === $name || strpos( $name, '||' ) === false ) {
			return $default;
		}

		$customizations = get_option( 'gfx_zeus_customizations' );
		if ( ! $customizations ) {
			return $default;
		}

		$attributes = explode( '||', $name );

		$selector = $attributes[0];
		$property = $attributes[1];

		if ( ! isset( $customizations[ $selector ] ) && ! isset( $customizations[ $selector ][ $property ] ) ) {
			return $default;
		}

		return $customizations[ $selector ][ $property ];

	}

}
