const { Icon } = wp.components;
const { createElement } = wp.element;

export const constructStyles = (attributes) => {
    const styles = {
        // general styles
        '--main-background-color': attributes.backgroundColor,
        // message styles
        '--personal-background-color': attributes.personalBackgroundColor,
        '--personal-text-color': attributes.personalTextColor,
        '--response-background-color': attributes.responseBackgroundColor,
        '--response-text-color': attributes.responseTextColor,
        // input
        '--input-background-color': attributes.inputBackgroundColor,
        '--input-border-color': attributes.inputBorderColor,
        '--input-text-color': attributes.inputTextColor,
        '--input-shadow-color': attributes.inputShadowColor,
        // button
        '--button-background-color': attributes.buttonBackgroundColor,
        '--button-background-color-hover':
            attributes.buttonBackgroundColorHover,
        '--button-text-color': attributes.buttonTextColor,
        '--button-text-color-hover': attributes.buttonTextColorHover,
        // welcome messsage
        '--welcome-message-color': attributes.welcomeMessageColor,
        '--welcome-icon-color': attributes.welcomeIconColor,
        '--welcome-icon-bg-color': attributes.welcomeIconBackgroundColor,
        // cta
        '--call-to-action-bg-color': attributes.ctaBgColor,
        '--call-to-action-bg-color-hover': attributes.ctaBgColorHover,
        '--call-to-action-icon-color': attributes.ctaIconColor,
        '--call-to-action-icon-color-hover': attributes.ctaIconColorHover,
    };

    return styles;
};

export const getChat = (attributes, isSave) => {
    const styles = constructStyles(attributes);

    return (
        <div className="gfx-zeus-chat-container" style={styles}>
            <div className="gfx-zeus-chat">
                <div className="gfx-zeus-chat-empty">
                    <div
                        className="icon"
                        dangerouslySetInnerHTML={{
                            __html: attributes.welcomeIcon,
                        }}
                    ></div>

                    {createElement(
                        attributes.welcomeMessageTag,
                        { className: 'message' },
                        attributes.welcomeMessage
                    )}
                </div>
                <div className="gfx-zeus-chat-conversation"></div>
                <form
                    className={`gfx-zeus-chat-form ${
                        attributes.ctaLink !== '' ? 'has-cta' : ''
                    }`}
                >
                    {attributes.ctaLink && (
                        <a
                            className="cta-btn hover-btn-1"
                            href={attributes.ctaLink}
                            target="_blank"
                            dangerouslySetInnerHTML={{
                                __html: attributes.ctaIcon,
                            }}
                        ></a>
                    )}

                    <div
                        className="gfx-zeus-chat-prompt"
                        autocomplete="off"
                        autocorrect="off"
                        spellcheck="true"
                        aria-expanded="false"
                        aria-autocomplete="list"
                        aria-multiline="true"
                        aria-label="Message"
                        dir="auto"
                        contenteditable="true"
                        role="textbox"
                        placeholder={attributes.PromptPlaceholder}
                    ></div>
                    <input
                        type="hidden"
                        name="chat-behaviour"
                        value={attributes.PromptBehaviour}
                    />
                    <button
                        className="submit"
                        type="submit"
                        disabled={!isSave}
                        dangerouslySetInnerHTML={{
                            __html: attributes.buttonIcon,
                        }}
                    ></button>
                </form>
            </div>
        </div>
    );
};
