import SettingsHandler from './scripts/settings';
import { transitionAnim } from './scripts/animations';
import formEventRegister, { colorPalleteHandler, toggleHandler } from './scripts/form';
import { chatlogView, deleteChat, deleteAllChatlogs, showDeletePopup, hideDeletePopup, chatlogFilter } from './scripts/chatlog';


if (typeof wp.blockEditor !== 'undefined') {
    import('./block/block');
    import('./toolbar/main');
}

const SERVICES = [SettingsHandler, formEventRegister];

window.addEventListener('load', () => {
    SERVICES.forEach((service) => {
        service();
    });
});

document.addEventListener('click', (e) => {
    // Is back button
    if (e.target.closest('.gfxzp-back-button')) {
        const parent = e.target.closest('.gfxzp-panel');
        
        if (parent.classList.contains('gfxzp-chatlog-panel-container') && parent.querySelector('.chatlog-log.active-visible')) {
            transitionAnim(
                '.chatlog-log',
                '.chatlog-content'
            );
        } else {
            transitionAnim(
                parent,
                '.gfxzp-dashboard-container'
            );
        }
    }

    // is box
    if (e.target.closest('.gfxzp-box')) {
        const parent = e.target.closest('.gfxzp-box');
        transitionAnim('.gfxzp-dashboard-container', parent.dataset.target);
    }

    if (e.target.closest('.color-choice:not(.color-choice-picker)')) {
        colorPalleteHandler(e.target.closest('.color-choice'));
    }

    if (e.target.closest('.color-choice.color-choice-picker')) {
        colorPalleteHandler(e.target.closest('.color-choice'));
    } else {
        const pickers = document.querySelectorAll('.colorPicker');
        if (pickers.length > 0) {
            pickers.forEach((picker) => picker.classList.remove('visible'));
        }
    }

    if (e.target.closest('.chatlog-box .view-icon') || e.target.closest('.chatlog-box h3')) {
        chatlogView(e);
    }

    if (e.target.closest('.chatlog-box .delete-icon')) {
        showDeletePopup(e);
    }

    if (e.target.closest('.popup-container .cancel-popup-button') || e.target.closest('.popup-container .cancel-popup-button')) {
        e.preventDefault();
        hideDeletePopup();
    }

    if (e.target.closest('.popup-container .delete-popup-button')) {
        deleteChat(e);
    }

    if (e.target.closest('.chatlog-delete-all')) {
        showDeletePopup(e);
    }

    if (e.target.closest('.zeusgpt-toggle') || e.target.closest('.zeusgpt-small-toggle')) {
        toggleHandler(e);
    }

    if (e.target.closest('.chatlog-filter-button')) {
        chatlogFilter(e);
    }

});
