import ToastifyParameters from '../data/toastify-parameters.json';

const formSubmitHandler = async (e) => {
    e.preventDefault();

    const submitEl = e.target.querySelector('[type="submit"]');
    submitEl.setAttribute('disabled', true);

    const formData = new FormData(e.target);
    formData.append('nonce', GFXZEUSOBJ['nonce']);

    let isEmpty = false;

    for (const entry of formData.entries()) {

        if (entry[0] === 'chatlog-delete-dialog-toggle') {
            if ( entry[1] === 'false' ) {
                document.body.classList.add('gfx-zeus-delete-popup-disabled');
            } else {
                document.body.classList.remove('gfx-zeus-delete-popup-disabled');
            }
        }

        if (entry[0].includes('||')) {
            const [selector, property] = entry[0].split('||');
            const el = document.querySelector(selector);
            if (el == null) continue;
            el.style.setProperty(property, entry[1]);
            continue;
        }
        if (entry[1] !== '') continue;
        isEmpty = true;
        const el = e.target.querySelector(`[name="${entry[0]}"]`);
        if (el == null) return;
        el.classList.add('error-empty');
    }

    if (isEmpty) {
        submitEl.removeAttribute('disabled');
        return;
    }

    const response = await fetch(GFXZEUSOBJ['ajax-url'], {
        method: 'POST',
        body: formData,
    });
    const resJSON = await response.json();

    if (!resJSON.success) {
        Toastify({
            ...ToastifyParameters,
            text: resJSON.data.message,
        }).showToast();
        submitEl.removeAttribute('disabled');
        return;
    }

    Toastify({
        ...ToastifyParameters,
        text: resJSON.data.message,
    }).showToast();

    submitEl.removeAttribute('disabled');

    if (formData.get('action') === 'gfx_zeus_api_key') {
        setTimeout(() => window.location.reload(), 1000);
    }
};

const colorPalleteChangeEvent = () => {
    const els = document.querySelectorAll('.color-pallete-wrapper');
    if (els.length < 1) return;
    els.forEach((el) => {
        const input = el.querySelector('input');
        if (input == null) return;
        input.addEventListener('change', (e) => {
            const target = e.target.dataset.target;
            const variable = e.target.dataset.variable;
            const value = e.target.value;
            if (value == null || value === '') return;
            if (variable == null || variable == '') return;
            if (target == null || target == '') return;
            document.querySelector(target).style.setProperty(variable, value);
        });
    });
};

const formEventRegister = () => {
    // color pallete events
    colorPalleteChangeEvent();

    // forms
    const forms = document.querySelectorAll(
        '.gfxzp-main-container form:not(.gfx-zeus-chat-form)'
    );
    if (forms.length < 1) return;
    forms.forEach((form) => {
        if (form.classList.contains('chat-form')) return;
        form.addEventListener('submit', formSubmitHandler);
    });
};

export const toggleHandler = (e) => {
    const parent = e.target.closest('.form-group');
    const input = parent.querySelector('input');
    const value = input.value;

    if ( value === 'true' ) {
        input.value = 'false';
        parent.querySelector('.zeusgpt-toggle-element').classList.remove('enabled');
    } else {
        input.value = 'true';
        parent.querySelector('.zeusgpt-toggle-element').classList.add('enabled');
    }
}

const colorPickerClickHandler = (element, input) => {
    const picker = element.querySelector('.colorPicker');
    const value = picker.dataset.value;
    if (value == null || value == '') return;

    picker.classList.add('visible');

    input.value = value;
    input.dispatchEvent(new Event('change'));
};

export const colorPalleteHandler = (element) => {
    if (element == null) return;
    const color = element.dataset.value;
    if (color == null || color === '') return;
    const parent = element.closest('.color-pallete');
    if (parent == null) return;
    const targetInput = parent.dataset.target;
    if (targetInput == null || targetInput === '') return;
    const input = parent.parentElement.querySelector(targetInput);
    if (input == null) return;

    if (element.classList.contains('color-choice-picker')) {
        colorPickerClickHandler(element, input);
    } else {
        input.value = color;
        input.dispatchEvent(new Event('change'));
    }

    // remove active classes
    const els = parent.querySelectorAll('.color-choice.active');
    if (els.length > 0) els.forEach((el) => el.classList.remove('active'));

    element.classList.add('active');
};

export default formEventRegister;
